#[repr(C)]pub struct DebugGetHostKoidResponse {
pub host_koid: u64,
}Fields
host_koid: u64Trait Implementations
Sourceimpl Clone for DebugGetHostKoidResponse
impl Clone for DebugGetHostKoidResponse
Sourcefn clone(&self) -> DebugGetHostKoidResponse
fn clone(&self) -> DebugGetHostKoidResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DebugGetHostKoidResponse
Sourceimpl Debug for DebugGetHostKoidResponse
impl Debug for DebugGetHostKoidResponse
Sourceimpl<___E> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DebugGetHostKoidResponse, ___E> for DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DebugGetHostKoidResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DebugGetHostKoidResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<DebugGetHostKoidResponse, ___E> for &'a DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DebugGetHostKoidResponse, ___E> for &'a DebugGetHostKoidResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DebugGetHostKoidResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DebugGetHostKoidResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, DebugGetHostKoidResponse>, ___E> for DebugGetHostKoidResponse
impl<___E> EncodeOption<Box<'static, DebugGetHostKoidResponse>, ___E> for DebugGetHostKoidResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DebugGetHostKoidResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DebugGetHostKoidResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DebugGetHostKoidResponse>, ___E> for &'a DebugGetHostKoidResponse
impl<'a, ___E> EncodeOption<Box<'static, DebugGetHostKoidResponse>, ___E> for &'a DebugGetHostKoidResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DebugGetHostKoidResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DebugGetHostKoidResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for DebugGetHostKoidResponse
Sourceimpl FromWire<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
impl FromWire<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DebugGetHostKoidResponse, Self>
Sourcefn from_wire(wire: DebugGetHostKoidResponse) -> Self
fn from_wire(wire: DebugGetHostKoidResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
impl FromWireRef<DebugGetHostKoidResponse> for DebugGetHostKoidResponse
Sourcefn from_wire_ref(wire: &DebugGetHostKoidResponse) -> Self
fn from_wire_ref(wire: &DebugGetHostKoidResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DebugGetHostKoidResponse
impl Hash for DebugGetHostKoidResponse
Sourceimpl Ord for DebugGetHostKoidResponse
impl Ord for DebugGetHostKoidResponse
Sourcefn cmp(&self, other: &DebugGetHostKoidResponse) -> Ordering
fn cmp(&self, other: &DebugGetHostKoidResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DebugGetHostKoidResponse
impl PartialEq for DebugGetHostKoidResponse
Sourceimpl PartialOrd for DebugGetHostKoidResponse
impl PartialOrd for DebugGetHostKoidResponse
impl StructuralPartialEq for DebugGetHostKoidResponse